@@ -11,8 +11,9 @@ class Task(irisml.core.TaskBase):
 
     If the condition is True, runs the tasks in 'then_tasks'. If the 'condition' is False, run the tasks in 'else_tasks'.
     """
-    VERSION = '0.1.0'
+    VERSION = '0.1.1'
     CACHE_ENABLED = False
+    RESOLVE_CONFIG_VARIABLES = False
 
     @dataclasses.dataclass
     class Config:
@@ -21,14 +22,19 @@ class Task(irisml.core.TaskBase):
         else_tasks: Optional[List[irisml.core.TaskDescription]] = dataclasses.field(default_factory=list)
 
     def execute(self, inputs):
-        logger.info(f"Condition is {self.config.condition}")
-        tasks = self.config.then_tasks if self.config.condition else self.config.else_tasks
+        return self._execute_core(inputs, dry_run=False)
+
+    def dry_run(self, inputs):
+        return self._execute_core(inputs, dry_run=True)
+
+    def _execute_core(self, inputs, dry_run):
+        resolved_condition = self.context.resolve(self.config.condition)
+        logger.info(f"Condition is {resolved_condition}")
+
+        tasks = self.config.then_tasks if resolved_condition else self.config.else_tasks
         for task_description in tasks:
             task = irisml.core.Task(task_description)
             task.load_module()
-            task.execute(self.context)
+            task.execute(self.context, dry_run=dry_run)
 
         return self.Outputs()
-
-    def dry_run(self, inputs):
-        return self.execute(inputs)
